aboutsummaryrefslogtreecommitdiffhomepage
path: root/src/gpu/GrReducedClip.h
diff options
context:
space:
mode:
authorGravatar halcanary <halcanary@google.com>2015-08-27 07:41:13 -0700
committerGravatar Commit bot <commit-bot@chromium.org>2015-08-27 07:41:16 -0700
commit96fcdcc219d2a0d3579719b84b28bede76efba64 (patch)
tree0ec5ea0193d8292df8bf5ed9dd8498a5eb5763dd /src/gpu/GrReducedClip.h
parent435af2f736c85c3274a0c6760a3523810750d237 (diff)
Style Change: NULL->nullptr
Diffstat (limited to 'src/gpu/GrReducedClip.h')
-rw-r--r--src/gpu/GrReducedClip.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/gpu/GrReducedClip.h b/src/gpu/GrReducedClip.h
index 21899c73aa..a0ce08a043 100644
--- a/src/gpu/GrReducedClip.h
+++ b/src/gpu/GrReducedClip.h
@@ -27,10 +27,10 @@ public:
* the list of elements is returned in resultGenID. The initial state of the
* query rectangle before the first clip element is applied is returned via
* initialState. Optionally, the caller can request a tighter bounds on the
* clip be returned via tighterBounds. If not NULL, tighterBounds will
* always be contained by queryBounds after return. If tighterBounds is
* specified then it is assumed that the caller will implicitly clip against
* it. If the caller specifies non-NULL for requiresAA then it will indicate
* whether anti-aliasing is required to process any of the elements in the
* result.
*
@@ -42,8 +42,8 @@ public:
ElementList* result,
int32_t* resultGenID,
InitialState* initialState,
- SkIRect* tighterBounds = NULL,
- bool* requiresAA = NULL);
+ SkIRect* tighterBounds = nullptr,
+ bool* requiresAA = nullptr);
};
#endif
@@ -27,10 +27,10 @@ public:
* query rectangle before the first clip element is applied is returned via
* initialState. Optionally, the caller can request a tighter bounds on the
- * clip be returned via tighterBounds. If not NULL, tighterBounds will
+ * clip be returned via tighterBounds. If not nullptr, tighterBounds will
* always be contained by queryBounds after return. If tighterBounds is
* specified then it is assumed that the caller will implicitly clip against
@@ -27,10 +27,10 @@ public:
* always be contained by queryBounds after return. If tighterBounds is
* specified then it is assumed that the caller will implicitly clip against
- * it. If the caller specifies non-NULL for requiresAA then it will indicate
+ * it. If the caller specifies non-nullptr for requiresAA then it will indicate
* whether anti-aliasing is required to process any of the elements in the
* result.